Sender

Struct Sender 

pub struct Sender<Head, Current, Tail>(/* private fields */)
where
    Head: Concat<(Current,)>,
    <Head as Concat<(Current,)>>::Output: Concat<Tail>,
    Tail: Tuple,
    <Whole<Head, Current, Tail> as Tuple>::TupleList: InElement;
The placer of an tuple slot.

The 3 generic represents the position of the target element of the tuple this sender attempts to place. For example, Sender<(A, B), C, (D, E, F)> represents a sender of C in (A, B, C, D, E, F).

The user can only access the slot once by this structure.

Implementations

Source

impl<Head, Current, Tail> Sender<Head, Current, Tail>
where Head: Concat<(Current,)>, <Head as Concat<(Current,)>>::Output: Concat<Tail>, Tail: Tuple, <Whole<Head, Current, Tail> as Tuple>::TupleList: InElement,

pub fn send(self, value: Current) -> Result<(), Take<Head, Current, Tail>>
where <Head as Tuple>::TupleList: Count, Place<Head, Current, Tail>: Index<CountOf<Head>, Output = Element<Current>>,

Place the value into the slot, or obtain the resulting tuple if no other senders exist any longer.